"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _react = require("react");
var _jsxRuntime = require("react/jsx-runtime");
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

class AutoClosableContextApi {
  constructor(ignoreNodesRef) {
    this.ignoreNodesRef = ignoreNodesRef;
    (0, _defineProperty2.default)(this, "children", []);
    (0, _defineProperty2.default)(this, "addChild", child => {
      this.children.push(child);
    });
    (0, _defineProperty2.default)(this, "removeChild", child => {
      this.children = this.children.filter(item => item !== child);
    });
    (0, _defineProperty2.default)(this, "getIgnoreNodes", () => {
      const nodes = [...this.ignoreNodesRef.current(), ...this.children.map(child => child.getIgnoreNodes()).flat()];
      return nodes.filter(node => node instanceof Node);
    });
  }
}
const AutoClosableContext = /*#__PURE__*/(0, _react.createContext)(null);
/**
 * This is helper component for handling outside clicks.
 * @since 0.0.42
 */
const AutoClosable = _ref => {
  let {
    onClose,
    ignoreNodes,
    nodeRef,
    children
  } = _ref;
  const onCloseRef = (0, _react.useRef)(onClose);
  onCloseRef.current = onClose;
  const getIgnoreNodes = () => [nodeRef?.current ?? null, ...(ignoreNodes?.() ?? [])];
  const ignoreNodesRef = (0, _react.useRef)(getIgnoreNodes);
  ignoreNodesRef.current = getIgnoreNodes;
  const parentContext = (0, _react.useContext)(AutoClosableContext);
  const autoClosableApi = (0, _react.useRef)(new AutoClosableContextApi(ignoreNodesRef)).current;
  (0, _react.useEffect)(() => {
    const handleClickOutside = event => {
      const element = event.target;
      const ignoreNodes = autoClosableApi.getIgnoreNodes();
      const isClickOnIgnoredNode = element instanceof Node && ignoreNodes.some(node => node.contains(element));
      if (isClickOnIgnoredNode) {
        return;
      }
      onCloseRef.current?.();
    };
    parentContext?.addChild(autoClosableApi);
    document.body.addEventListener('click', handleClickOutside, {
      capture: true
    });
    return () => {
      parentContext?.removeChild(autoClosableApi);
      document.body.removeEventListener('click', handleClickOutside, {
        capture: true
      });
    };
  }, [parentContext, autoClosableApi]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(AutoClosableContext.Provider, {
    value: autoClosableApi,
    children: children
  });
};
var _default = exports.default = AutoClosable;