"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findNextSafeIndex = exports.default = void 0;
var _react = require("react");
var _constants = require("../../constants");
var _classnames = _interopRequireDefault(require("classnames"));
var _Popper = _interopRequireDefault(require("../Popper"));
var _Menu = _interopRequireWildcard(require("../Menu"));
var _AutoClosable = _interopRequireDefault(require("../AutoClosable"));
var _utils = require("../utils");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function (e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != typeof e && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (const t in e) "default" !== t && {}.hasOwnProperty.call(e, t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, t)) && (i.get || i.set) ? o(f, t, i) : f[t] = e[t]); return f; })(e, t); }
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

const findNextSafeIndex = (currIndex, diff, options) => {
  const maxIndex = options.length - 1;
  let attempt = 0;
  for (let i = currIndex + diff; attempt < options.length; i += diff) {
    attempt += 1;
    if (i > maxIndex) {
      i = 0;
    } else if (i < 0) {
      i = maxIndex;
    }
    if (options[i] && options[i].disabled === false) {
      return i;
    }
  }
  return -1;
};
exports.findNextSafeIndex = findNextSafeIndex;
const ComboBoxDropdown = _ref => {
  let {
    baseClassName = `${_constants.CLS_PREFIX}combobox-dropdown`,
    className,
    control,
    controlRef,
    opened,
    disabled,
    groups,
    options,
    onHighlightedIndexChange,
    onClose,
    value,
    highlightedIndex,
    onSelect,
    noOptions,
    emitter,
    listboxId,
    ...props
  } = _ref;
  const rootRef = (0, _react.useRef)(null);
  const menuRef = (0, _react.useRef)(null);
  const [minWidth, setMinWidth] = (0, _react.useState)(0);
  (0, _react.useLayoutEffect)(() => {
    if (opened && rootRef.current) {
      const {
        width
      } = rootRef.current.getBoundingClientRect();
      if (width !== minWidth) {
        setMinWidth(width);
      }
    }
  }, [opened, minWidth]);
  (0, _react.useEffect)(() => {
    if (!opened) {
      return undefined;
    }
    const listener = () => {
      (0, _utils.safeInvoke)(onClose);
    };
    window.addEventListener('resize', listener, {
      once: true
    });
    return () => window.removeEventListener('resize', listener);
  }, [opened, onClose]);
  (0, _react.useEffect)(() => {
    if (!emitter) {
      return;
    }
    emitter.on('focus', index => {
      if (menuRef.current) {
        const target = menuRef.current.querySelector(`[data-index="${index}"]`);
        if (target) {
          (0, _utils.scrollIntoView)(target, {
            behavior: 'instant',
            block: 'nearest',
            boundary: menuRef.current
          });
        }
      }
    });
  }, [emitter]);
  const target = /*#__PURE__*/(0, _jsxRuntime.jsx)(_AutoClosable.default, {
    onClose: () => {
      setTimeout(() => {
        (0, _utils.safeInvoke)(onClose);
      }, 0);
    },
    ignoreNodes: () => [menuRef.current],
    nodeRef: controlRef,
    children: control
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
    className: className,
    ...props,
    ref: rootRef,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Popper.default, {
      target: target,
      targetRef: controlRef,
      show: opened && !disabled,
      className: `${baseClassName}__popper`,
      zIndex: _constants.Z_INDEX_DROPDOWN,
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Menu.default, {
        style: {
          minWidth
        },
        ref: menuRef,
        className: `${baseClassName}__menu`,
        role: "listbox",
        id: listboxId,
        children: [groups.reduce((acc, group) => {
          if (group.label) {
            acc.push(/*#__PURE__*/(0, _react.createElement)(_Menu.MenuHeader, {
              ...group.props,
              key: `group_${group.label}`
            }, group.label));
          }
          group.options.forEach(option => {
            const optionIndex = options.indexOf(option);
            let onClick;
            let onMouseOver;
            let onMouseDown;
            if (!option.disabled) {
              onClick = e => {
                e.preventDefault();
                (0, _utils.safeInvoke)(onSelect, option.value);
              };
              onMouseOver = () => {
                // TODO: use throttle
                (0, _utils.safeInvoke)(onHighlightedIndexChange, optionIndex);
              };
              onMouseDown = e => {
                e.preventDefault();
              };
            }
            const menuItemProps = {
              ...option.props,
              active: value === option.value,
              className: (0, _classnames.default)(`${baseClassName}__option`, {
                [`${baseClassName}__option--selected`]: optionIndex === highlightedIndex
              }),
              disabled: option.disabled,
              onClick,
              onMouseOver,
              onMouseDown,
              'data-index': optionIndex
            };
            acc.push(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Menu.MenuItem, {
              ...menuItemProps,
              children: option.children
            }, `option_${option.value}`));
          });
          return acc;
        }, []), options.length === 0 && noOptions && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Menu.MenuItem, {
          disabled: true,
          className: `${baseClassName}__no-options`,
          children: noOptions
        })]
      })
    })
  });
};
var _default = exports.default = ComboBoxDropdown;