"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _react = require("react");
var _classnames = _interopRequireDefault(require("classnames"));
var _constants = require("../../constants");
var _jsxRuntime = require("react/jsx-runtime");
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

const scrollToBottom = el => {
  el.scrollTop = el.scrollHeight;
};
/**
 * `ConsoleOutput` component is used for showing dynamically updating data from console output.
 * @since 0.0.35
 */
class ConsoleOutput extends _react.PureComponent {
  constructor() {
    super(...arguments);
    (0, _defineProperty2.default)(this, "rootRef", /*#__PURE__*/(0, _react.createRef)());
    (0, _defineProperty2.default)(this, "prevScrollTop", 0);
    (0, _defineProperty2.default)(this, "autoscrollCancelled", false);
    (0, _defineProperty2.default)(this, "handleScroll", () => {
      const el = this.rootRef.current;
      if (!el) {
        return;
      }
      if (el.scrollTop < this.prevScrollTop) {
        this.autoscrollCancelled = true;
      } else if (el.clientHeight + el.scrollTop >= el.scrollHeight) {
        this.autoscrollCancelled = false;
      }
    });
  }
  componentDidMount() {
    const {
      autoscroll
    } = this.props;
    const el = this.rootRef.current;
    if (autoscroll && el) {
      scrollToBottom(el);
    }
  }
  componentDidUpdate() {
    const {
      autoscroll
    } = this.props;
    const el = this.rootRef.current;
    if (autoscroll && el) {
      this.prevScrollTop = el.scrollTop;
      if (!this.autoscrollCancelled) {
        scrollToBottom(el);
      }
    }
  }
  render() {
    const {
      baseClassName,
      className,
      wide,
      cursor,
      children,
      autoscroll,
      ...props
    } = this.props;
    const onScroll = autoscroll ? this.handleScroll : undefined;
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)("pre", {
      className: (0, _classnames.default)(baseClassName, {
        [`${baseClassName}--wide`]: wide
      }, className),
      ref: this.rootRef,
      onScroll: onScroll,
      ...props,
      children: [children, cursor ? /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
        className: `${baseClassName}__cursor`
      }) : null]
    });
  }
}
(0, _defineProperty2.default)(ConsoleOutput, "defaultProps", {
  baseClassName: `${_constants.CLS_PREFIX}console-output`,
  wide: false,
  cursor: false,
  autoscroll: true
});
var _default = exports.default = ConsoleOutput;