"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SECTION_BASE_CLASS_NAME = void 0;
var _classnames = _interopRequireDefault(require("classnames"));
var _react = require("react");
var _constants = require("../../constants");
var _Button = _interopRequireDefault(require("../Button"));
var _InPlaceEdit = _interopRequireDefault(require("../InPlaceEdit"));
var _utils = require("../utils");
var _VerticalContext = _interopRequireDefault(require("../VerticalContext"));
var _SectionContext = _interopRequireDefault(require("./SectionContext"));
var _useCollapsed = require("./useCollapsed");
var _useVertical = require("./useVertical");
var _jsxRuntime = require("react/jsx-runtime");
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

const SECTION_BASE_CLASS_NAME = exports.SECTION_BASE_CLASS_NAME = `${_constants.CLS_PREFIX}section`;

/**
 * `Section` component is used for dividing of complex content into groups for better readability
 * and comprehension of the presented information.
 * @since 0.0.54
 */
const Section = _ref => {
  let {
    baseClassName = SECTION_BASE_CLASS_NAME,
    className,
    intent,
    collapsible = false,
    collapsed: externalCollapsed = false,
    onToggle,
    title,
    onTitleChange,
    onClose,
    buttons,
    vertical: externalVertical,
    children,
    ...props
  } = _ref;
  const containerRef = (0, _react.useRef)(null);
  const collapseButtonRef = (0, _react.useRef)(null);
  const vertical = (0, _useVertical.useVertical)(externalVertical, containerRef);
  const [collapsed, setCollapsed] = (0, _useCollapsed.useCollapsed)(externalCollapsed);
  const toggleCollapsed = () => {
    setCollapsed(prevCollapsed => {
      onToggle?.(!prevCollapsed);
      return !prevCollapsed;
    });
  };
  const parentSectionContext = (0, _react.useContext)(_SectionContext.default);
  const sectionContextValue = (0, _react.useMemo)(() => ({
    expand: () => {
      parentSectionContext?.expand();
      setCollapsed(false);
    }
  }), [setCollapsed, parentSectionContext]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_SectionContext.default.Provider, {
    value: sectionContextValue,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_VerticalContext.default.Provider, {
      value: vertical,
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        ref: containerRef,
        className: (0, _classnames.default)(baseClassName, {
          [`${baseClassName}--${intent}`]: intent,
          [`${baseClassName}--collapsible`]: collapsible,
          [`${baseClassName}--collapsed`]: collapsed,
          [`${baseClassName}--vertical`]: vertical
        }, className),
        ...props,
        children: [title && /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
          className: `${baseClassName}__header`,
          children: [collapsible && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.default, {
            ref: collapseButtonRef,
            ghost: true,
            className: (0, _classnames.default)(`${baseClassName}__control-button`, `${baseClassName}__control-button--collapse`),
            icon: {
              name: 'chevron-up',
              flipVertical: collapsed
            },
            onClick: toggleCollapsed,
            "aria-expanded": !collapsed
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_InPlaceEdit.default, {
            className: `${baseClassName}__title`,
            value: title,
            onChange: onTitleChange,
            onClick: e => {
              if (!collapsible || (0, _utils.isClickable)(e)) {
                return;
              }
              collapseButtonRef.current?.click();
            }
          }), (onClose || buttons) && /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
            className: `${baseClassName}__header-buttons`,
            children: [buttons, onClose && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.default, {
              ghost: true,
              className: (0, _classnames.default)(`${baseClassName}__control-button`, `${baseClassName}__control-button--close`),
              onClick: onClose,
              icon: "cross-mark"
            })]
          })]
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          style: {
            display: collapsed ? 'none' : undefined
          },
          children: children
        })]
      })
    })
  });
};
var _default = exports.default = Section;