"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _classnames = _interopRequireDefault(require("classnames"));
var _Dropdown = _interopRequireDefault(require("../Dropdown"));
var _Icon = _interopRequireDefault(require("../Icon"));
var _Menu = _interopRequireWildcard(require("../Menu"));
var _Tab = _interopRequireDefault(require("./Tab"));
var _TabClose = _interopRequireDefault(require("./TabClose"));
var _TabIcon = _interopRequireDefault(require("./TabIcon"));
var _TabLabel = _interopRequireDefault(require("./TabLabel"));
var _TabListItem = _interopRequireDefault(require("./TabListItem"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function (e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != typeof e && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (const t in e) "default" !== t && {}.hasOwnProperty.call(e, t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, t)) && (i.get || i.set) ? o(f, t, i) : f[t] = e[t]); return f; })(e, t); }
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

const TabList = _ref => {
  let {
    children,
    tabListRef,
    active,
    onTabClick,
    visibleLength,
    monospacedWidth,
    baseClassName,
    tabPanelId,
    idPrefix
  } = _ref;
  const handleTabClick = (tab, position) => {
    onTabClick(position);
    tab?.props?.onActivate?.();
  };
  const childArray = _react.Children.map(children, (child, index) => ({
    child,
    position: index + 1
  }));
  const tabs = childArray.filter(_ref2 => {
    let {
      child
    } = _ref2;
    return child?.type === _Tab.default;
  });
  const listChildren = tabs.slice(0, visibleLength);
  const menuChildren = tabs.slice(visibleLength);
  const listItems = listChildren.map(_ref3 => {
    let {
      child: tab,
      position
    } = _ref3;
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_TabListItem.default, {
      tab: tab,
      baseClassName: baseClassName,
      selected: position === active,
      onClick: () => handleTabClick(tab, position),
      monospacedWidth: monospacedWidth,
      tabPanelId: tabPanelId,
      id: idPrefix ? `${idPrefix}-${position}` : undefined
    }, position);
  });
  const menuItems = menuChildren.map(_ref4 => {
    let {
      child: tab,
      position
    } = _ref4;
    const {
      title,
      label,
      icon,
      onActivate,
      onClose,
      component: Tag = 'a',
      ...tabProps
    } = tab.props;
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Menu.MenuItem, {
      icon: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TabIcon.default, {
        icon: icon,
        baseClassName: baseClassName
      }),
      label: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_TabLabel.default, {
          label: label,
          tabMode: "menu-item",
          baseClassName: baseClassName
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_TabClose.default, {
          onClose: onClose,
          tabMode: "menu-item",
          baseClassName: baseClassName
        })]
      }),
      active: active === position,
      onClick: () => handleTabClick(tab, position),
      className: `${baseClassName}__menu-item`,
      component: Tag,
      ...tabProps,
      children: title
    }, position);
  });
  const moreSelected = active > listChildren.length;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)("ul", {
    ref: tabListRef,
    className: `${baseClassName}__tab-list`,
    role: "tablist",
    "aria-labelledby": tabPanelId,
    children: [listItems, menuItems.length > 0 && /*#__PURE__*/(0, _jsxRuntime.jsx)("li", {
      className: (0, _classnames.default)(`${baseClassName}__tab`, moreSelected && `${baseClassName}__tab--selected`, `${baseClassName}__tab--more`),
      role: "presentation",
      "aria-selected": moreSelected || undefined,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Dropdown.default, {
        className: `${baseClassName}__dropdown`,
        menu: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Menu.default, {
          children: menuItems
        }),
        menuPlacement: "bottom-end",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)("a", {
          className: `${baseClassName}__link`,
          role: "tab",
          tabIndex: 0,
          "aria-selected": moreSelected || undefined,
          onKeyDown: e => {
            if (e.key === 'Enter') {
              e.currentTarget.click();
            }
          },
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
            name: "three-dots-horizontal"
          })
        })
      })
    })]
  });
};
var _default = exports.default = TabList;