"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _classnames = _interopRequireDefault(require("classnames"));
var _react = require("react");
var _constants = require("../../constants");
var _ResponsiveContext = _interopRequireDefault(require("../ResponsiveContext"));
var _FakeTabs = _interopRequireDefault(require("./FakeTabs"));
var _TabList = _interopRequireDefault(require("./TabList"));
var _useActive = require("./useActive");
var _useWidths = require("./useWidths");
var _jsxRuntime = require("react/jsx-runtime");
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

/**
 * `Tabs` component is a content area with a group of individual [Tab](#!/Tab) elements, each displaying different content
 * in the same screen area. `Tabs` are used when you have too much content to display in one place at the same time, so
 * the content is broken into logical groups and each group is displayed under its own [Tab](#!/Tab) that serves both as a
 * group name and a navigation button.
 * @since 0.0.35
 */
const Tabs = _ref => {
  let {
    baseClassName = `${_constants.CLS_PREFIX}tabs`,
    className,
    addon,
    placeholder,
    children,
    active: externalActive,
    addonMinWidth,
    monospaced,
    search,
    ...props
  } = _ref;
  const addonElement = addon || placeholder;
  const tabNavRef = (0, _react.useRef)(null);
  const tabListRef = (0, _react.useRef)(null);
  const addonRef = (0, _react.useRef)(null);
  const childrenCount = _react.Children.toArray(children).length;
  const wrappedAddonElement = addonElement ? /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
    ref: addonRef,
    children: addonElement
  }) : null;
  const [active, setActive] = (0, _useActive.useActive)(externalActive);
  const {
    monospacedWidth,
    recalculateWidths,
    compact,
    visibleLength
  } = (0, _useWidths.useWidths)({
    monospaced,
    tabNavRef,
    tabListRef,
    addonRef,
    baseClassName,
    childrenCount
  });
  const [searching, setSearching] = (0, _react.useState)(false);
  const id = (0, _react.useId)();
  if (!childrenCount) {
    return null;
  }
  const renderSearchBar = () => {
    if (!search) {
      return null;
    }
    const handleStartSearching = () => setSearching(true);
    const handleCancelSearching = () => setSearching(false);
    const searchProps = {
      className: `${baseClassName}__search-bar`,
      collapsable: compact,
      onExpand: handleStartSearching,
      onCollapse: handleCancelSearching,
      ...(searching ? {
        autoFocus: true,
        responsive: false,
        maxWidth: 'none',
        minWidth: 'unset'
      } : {})
    };
    const clone = /*#__PURE__*/(0, _react.cloneElement)(search, searchProps);
    if (compact) {
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_ResponsiveContext.default.Provider, {
        value: true,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
          className: `${baseClassName}__search`,
          children: clone
        })
      });
    }
    return clone;
  };
  const addonStyle = {};
  if (search && !compact) {
    addonStyle.maxWidth = search.props.maxWidth;
  }
  const tabPanelId = `${id}-tabpanel`;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
    className: (0, _classnames.default)(baseClassName, className),
    ...props,
    children: [compact && wrappedAddonElement && /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      className: `${baseClassName}__addon ${baseClassName}__addon--compact`,
      children: wrappedAddonElement
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
      className: (0, _classnames.default)(`${baseClassName}__nav`, compact && `${baseClassName}__nav--compact`, searching && `${baseClassName}__nav--searching`, search && `${baseClassName}__nav--search`),
      ref: tabNavRef,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_TabList.default, {
        tabListRef: tabListRef,
        active: active,
        onTabClick: setActive,
        visibleLength: visibleLength,
        monospacedWidth: monospacedWidth,
        baseClassName: baseClassName,
        tabPanelId: tabPanelId,
        children: children
      }), compact && renderSearchBar(), !compact && (wrappedAddonElement || search) && /*#__PURE__*/(0, _jsxRuntime.jsxs)("div", {
        className: `${baseClassName}__addon`,
        style: addonStyle,
        children: [renderSearchBar(), wrappedAddonElement]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_FakeTabs.default, {
        onResize: recalculateWidths,
        baseClassName: baseClassName,
        children: children
      })]
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
      id: tabPanelId,
      className: `${baseClassName}__tab-panel`,
      role: "tabpanel",
      "aria-labelledby": `${id}-${active}`,
      children: _react.Children.map(children, (tab, index) => index + 1 === active ? tab : null)
    })]
  });
};
var _default = exports.default = Tabs;