"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepareIconName = exports.isRtl = exports.enableDocumentScroll = exports.disableDocumentScroll = exports.copyToClipboard = void 0;
var _react = require("react");
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

const isRtl = () => getComputedStyle(document.documentElement).direction === 'rtl';
exports.isRtl = isRtl;
let hasDocumentScroll = true;
const disableDocumentScroll = () => {
  if (hasDocumentScroll) {
    const top = `${-window.pageYOffset}px`;
    document.documentElement.style.position = 'fixed';
    document.body.style.marginTop = top;
    hasDocumentScroll = false;
  }
};
exports.disableDocumentScroll = disableDocumentScroll;
const enableDocumentScroll = () => {
  if (!hasDocumentScroll) {
    const scrollTop = Math.abs(parseInt(document.body.style.marginTop || '0'));
    document.documentElement.style.position = '';
    document.body.style.marginTop = '';
    window.scrollTo(0, scrollTop);
    hasDocumentScroll = true;
  }
};
exports.enableDocumentScroll = enableDocumentScroll;
const copyToClipboard = value => {
  const el = document.createElement('textarea');
  el.value = value;
  el.setAttribute('readonly', '');
  el.style.position = 'absolute';
  el.style.left = '-9999px';
  document.body.appendChild(el);
  el.select();
  document.execCommand('copy');
  document.body.removeChild(el);
};
exports.copyToClipboard = copyToClipboard;
const prepareIconName = (icon, empty) => {
  if (!empty || !icon) {
    return undefined;
  }
  const formatName = name => `${name.replace(/-/g, ' ')} icon`;
  if (typeof icon === 'string') {
    return formatName(icon);
  }
  if (/*#__PURE__*/(0, _react.isValidElement)(icon) && typeof icon.props.name === 'string') {
    return formatName(icon.props.name);
  }
  return undefined;
};
exports.prepareIconName = prepareIconName;