import _defineProperty from "@babel/runtime/helpers/defineProperty";
// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

import { Component, Fragment, createRef } from 'react';
import classNames from 'classnames';
import { CLS_PREFIX } from '../../constants';
import Button from '../Button';
import FormField from '../FormField';
import Input from '../Input';
import Toast from '../Toast';
import { InternalTranslate } from '../Translate';
import PasswordMeter from './PasswordMeter';
import generatePassword from './generatePassword';
import { copyToClipboard } from '../../utils';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * `FormFieldPassword` component provides secure way to enter a password.
 * @since 0.0.58
 */
class FormFieldPassword extends Component {
  constructor() {
    super(...arguments);
    _defineProperty(this, "state", {
      copyToastVisible: false,
      visible: false,
      passwordMeterVisible: false,
      passwordGenerated: false
    });
    _defineProperty(this, "targetRef", /*#__PURE__*/createRef());
    _defineProperty(this, "handleToggleClick", () => {
      this.setState(_ref => {
        let {
          visible
        } = _ref;
        return {
          visible: !visible
        };
      });
    });
    _defineProperty(this, "handleClosePasswordMeter", () => {
      this.setState({
        passwordMeterVisible: false
      });
    });
    _defineProperty(this, "handleBlur", this.handleClosePasswordMeter);
    _defineProperty(this, "handleCopyToClipboard", contentToCopy => {
      copyToClipboard(contentToCopy);
      this.setState({
        copyToastVisible: true
      });
    });
  }
  renderCopyButton(_ref2) {
    let {
      value,
      isDisabled
    } = _ref2;
    const {
      baseClassName,
      copyButton
    } = this.props;
    const copyButtonProps = {
      className: `${baseClassName}__button--copy`,
      icon: 'copy',
      onClick: () => this.handleCopyToClipboard(value),
      tooltip: /*#__PURE__*/_jsx(InternalTranslate, {
        content: "FormFieldPassword.copyButtonHint"
      }),
      disabled: isDisabled()
    };
    let button;
    if (typeof copyButton === 'function') {
      button = copyButton(copyButtonProps);
    } else {
      button = /*#__PURE__*/_jsx(Button, {
        ...copyButtonProps
      });
    }
    return /*#__PURE__*/_jsxs(Fragment, {
      children: [` `, button]
    });
  }
  renderGenerateButton(_ref3) {
    let {
      setValue,
      isDisabled
    } = _ref3;
    const {
      baseClassName,
      generateButton
    } = this.props;
    const generateButtonProps = {
      className: `${baseClassName}__button--generate`,
      onClick: () => {
        setValue(generatePassword());
        this.setState({
          passwordGenerated: true
        });
      },
      tooltip: /*#__PURE__*/_jsx(InternalTranslate, {
        content: "FormFieldPassword.generateButtonHint"
      }),
      disabled: isDisabled(),
      children: /*#__PURE__*/_jsx(InternalTranslate, {
        content: "FormFieldPassword.generateButton"
      })
    };
    let button;
    if (typeof generateButton === 'function') {
      button = generateButton(generateButtonProps);
    } else {
      button = /*#__PURE__*/_jsx(Button, {
        ...generateButtonProps
      });
    }
    return /*#__PURE__*/_jsxs(Fragment, {
      children: [` `, button]
    });
  }
  render() {
    const {
      baseClassName,
      className,
      hideShowButton,
      copyButton,
      generateButton,
      hideCopyButton,
      hideGenerateButton,
      hidePasswordMeter,
      passwordMeterProps,
      size,
      autoFocus,
      autoComplete,
      ...props
    } = this.props;
    const {
      visible,
      passwordMeterVisible
    } = this.state;
    return /*#__PURE__*/_jsx(FormField, {
      className: classNames(baseClassName, className),
      ...props,
      children: _ref4 => {
        let {
          getId,
          getName,
          getValue,
          setValue,
          getErrors,
          isDisabled,
          getDescriptionLabelId
        } = _ref4;
        const value = getValue('');
        const input = /*#__PURE__*/_jsx(Input, {
          id: getId(),
          name: getName(),
          type: visible ? 'text' : 'password',
          value: value,
          onChange: e => {
            setValue(e.target.value);
            this.setState({
              passwordMeterVisible: true
            });
          },
          onBlur: this.handleBlur,
          autoFocus: autoFocus,
          autoComplete: autoComplete,
          className: `${baseClassName}__input`,
          size: size,
          "aria-invalid": !!Object.keys(getErrors() ?? {}).length,
          "aria-describedby": getDescriptionLabelId(),
          suffix: hideShowButton ? null : /*#__PURE__*/_jsx(Button, {
            className: `${baseClassName}__button--show`,
            onClick: this.handleToggleClick,
            icon: visible ? 'visible' : 'invisible',
            tooltip: visible ? /*#__PURE__*/_jsx(InternalTranslate, {
              content: "FormFieldPassword.hidePassword"
            }) : /*#__PURE__*/_jsx(InternalTranslate, {
              content: "FormFieldPassword.showPassword"
            }),
            ghost: true,
            disabled: isDisabled()
          }),
          disabled: isDisabled(),
          rootProps: {
            ref: this.targetRef
          }
        });
        return /*#__PURE__*/_jsxs("div", {
          className: classNames(`${baseClassName}__control`, `${baseClassName}__control--${size}`),
          children: [this.state.copyToastVisible && /*#__PURE__*/_jsx("div", {
            className: `${baseClassName}__toast`,
            children: /*#__PURE__*/_jsx(Toast, {
              autoClosable: true,
              onClose: () => this.setState({
                copyToastVisible: false
              }),
              icon: "check-mark-circle-filled",
              intent: "success",
              message: /*#__PURE__*/_jsx(InternalTranslate, {
                content: "FormFieldPassword.copySuccessToast"
              })
            })
          }), /*#__PURE__*/_jsx("div", {
            className: classNames(`${baseClassName}__field`, `${baseClassName}__field--${size}`),
            children: hidePasswordMeter ? input : /*#__PURE__*/_jsx(PasswordMeter, {
              value: value,
              targetRef: this.targetRef,
              visible: passwordMeterVisible && value !== '',
              onClose: this.handleClosePasswordMeter,
              ...passwordMeterProps,
              children: input
            })
          }), hideGenerateButton ? null : this.renderGenerateButton({
            setValue,
            isDisabled
          }), hideCopyButton || !this.state.passwordGenerated ? null : this.renderCopyButton({
            value,
            isDisabled
          })]
        });
      }
    });
  }
}
_defineProperty(FormFieldPassword, "defaultProps", {
  hideShowButton: false,
  copyButton: undefined,
  generateButton: undefined,
  hideCopyButton: false,
  hideGenerateButton: false,
  hidePasswordMeter: false,
  passwordMeterProps: {},
  size: 'md',
  autoFocus: undefined,
  autoComplete: undefined,
  className: undefined,
  baseClassName: `${CLS_PREFIX}form-field-password`
});
export default FormFieldPassword;