// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

import Label from '../Label';
import Tooltip from '../Tooltip';
import { useInternalTranslate } from '../LocaleProvider';
import { jsx as _jsx } from "react/jsx-runtime";
const GroupLabel = _ref => {
  let {
    group,
    onClose
  } = _ref;
  const {
    renderHeaderLabel,
    renderHeaderLabelTitle,
    closable = false,
    renderHeaderLabelTooltip,
    intent
  } = group;
  const translate = useInternalTranslate('Toaster');
  if (!renderHeaderLabel && !renderHeaderLabelTitle) {
    return null;
  }
  const handleClick = closable ? onClose : undefined;
  const labelProps = {
    intent,
    onClick: handleClick,
    icon: closable ? 'cross-mark' : undefined,
    children: renderHeaderLabelTitle ? renderHeaderLabelTitle(group) : null,
    caps: false,
    size: 'md'
  };
  if (renderHeaderLabel) {
    return renderHeaderLabel(group, labelProps);
  }
  const wrapInTooltip = content => {
    if (!renderHeaderLabelTooltip && !closable) return content;
    const title = renderHeaderLabelTooltip?.(group) ?? translate('closeGroup');
    if (!title) return content;
    return /*#__PURE__*/_jsx(Tooltip, {
      title: title,
      children: content
    });
  };
  const label = /*#__PURE__*/_jsx(Label, {
    ...labelProps
  });
  return wrapInTooltip(label);
};
export default GroupLabel;