// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

import { useEffect, useRef } from 'react';
export const useResizeObserver = _ref => {
  let {
    ref,
    onResize,
    callOnInit = true
  } = _ref;
  const isInitial = useRef(true);
  const onResizeRef = useRef(undefined);
  onResizeRef.current = onResize;
  useEffect(() => {
    if (!ref.current) return undefined;
    if (typeof window === 'undefined' || !('ResizeObserver' in window)) return undefined;
    const observer = new ResizeObserver(() => {
      if (!callOnInit && isInitial.current) {
        isInitial.current = false;
        return;
      }
      onResizeRef.current?.();
    });
    observer.observe(ref.current);
    return () => {
      observer.disconnect();
    };
  }, [ref, callOnInit]);
};