// Copyright 1999-2025. WebPros International GmbH. All rights reserved.

import { isValidElement } from 'react';
export const isRtl = () => getComputedStyle(document.documentElement).direction === 'rtl';
let hasDocumentScroll = true;
export const disableDocumentScroll = () => {
  if (hasDocumentScroll) {
    const top = `${-window.pageYOffset}px`;
    document.documentElement.style.position = 'fixed';
    document.body.style.marginTop = top;
    hasDocumentScroll = false;
  }
};
export const enableDocumentScroll = () => {
  if (!hasDocumentScroll) {
    const scrollTop = Math.abs(parseInt(document.body.style.marginTop || '0'));
    document.documentElement.style.position = '';
    document.body.style.marginTop = '';
    window.scrollTo(0, scrollTop);
    hasDocumentScroll = true;
  }
};
export const copyToClipboard = value => {
  const el = document.createElement('textarea');
  el.value = value;
  el.setAttribute('readonly', '');
  el.style.position = 'absolute';
  el.style.left = '-9999px';
  document.body.appendChild(el);
  el.select();
  document.execCommand('copy');
  document.body.removeChild(el);
};
export const prepareIconName = (icon, empty) => {
  if (!empty || !icon) {
    return undefined;
  }
  const formatName = name => `${name.replace(/-/g, ' ')} icon`;
  if (typeof icon === 'string') {
    return formatName(icon);
  }
  if (/*#__PURE__*/isValidElement(icon) && typeof icon.props.name === 'string') {
    return formatName(icon.props.name);
  }
  return undefined;
};