import { FunctionComponent, ReactNode, ReactElement, ElementType, MouseEvent } from 'react';
import { IconProps } from '../Icon';
import '../../helpers/base.less';
import './Action.less';
export type ActionProps = {
    /**
     * Content of the `Action`.
     * @since 0.0.68
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * Useful when rendering an `Action` as `<Link>` instead `<a>`.
     * @since 0.0.68
     */
    component?: string | ElementType;
    /**
     * Icon of the Action.
     * @since 0.0.68
     */
    icon?: string | IconProps | ReactElement<any>;
    /**
     * Right additional content.
     * @since 0.0.68
     */
    rightAddon?: ReactNode;
    /**
     * Bottom additional content.
     * @since 0.0.68
     */
    bottomAddon?: ReactNode;
    /**
     * Indicate the progress state of the `Action`.
     * @since 1.1.0
     */
    progress?: boolean;
    /**
     * Component visual emphasis
     * @since 3.36.0
     */
    primary?: boolean;
    /**
     * Suppresses line breaks (text wrapping) within the source.
     * @since 0.0.68
     */
    nowrap?: boolean;
    /**
     * Props for the outer element.
     * @since 0.0.68
     */
    outerProps?: {
        className?: string;
        component?: string | ElementType;
    };
    /**
     * @ignore
     */
    onClick?: (e: MouseEvent<HTMLElement>) => void;
} & {
    [key: string]: any;
};
/**
 * `Action` component is used mostly for navigation, to go between pages, and not for immediate action or submitting data.
 * @since 0.0.68
 */
declare const Action: FunctionComponent<ActionProps>;
export default Action;
