import { ReactNode, CSSProperties } from 'react';
import { DataAttributes } from '../../utils/types';
import './PreviewPanel.less';
type PreviewPanelProps = {
    /**
     * Background image content.
     * @since 0.3.0
     */
    background?: string;
    /**
     * Image content.
     * @since 0.3.0
     */
    image?: string;
    /**
     * Padding of image content (in pixels). Could be a number or an array of numbers. Behavior as in CSS property `padding`.
     * @since 0.3.0
     */
    padding?: number | [number, number];
    /**
     * Alt property for an image.
     * @since 0.3.0
     */
    alt?: string;
    /**
     * Custom content for hover over preview panel. Hidden in card for the row view.
     * @since 0.3.0
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    style?: CSSProperties;
    /**
     * HTML content. Width of content will be adjusted to fit preview panel.
     * @ignore
     * @deprecated
     */
    html?: string;
} & DataAttributes;
/**
 * `PreviewPanel` component is used for displaying website preview.
 * @since 0.3.0
 */
declare const PreviewPanel: ({ background, image, padding, alt, children, className, baseClassName, html, ...props }: PreviewPanelProps) => import("react/jsx-runtime").JSX.Element;
export default PreviewPanel;
