import { ReactNode, HTMLProps, FunctionComponent } from 'react';
import './Checkbox.less';
export type CheckboxProps = {
    /**
     * Determine whether the `Checkbox` is checked.
     * @since 0.0.55
     */
    checked?: boolean;
    /**
     * @ignore
     */
    defaultChecked?: boolean;
    /**
     * A callback function, can be executed when the checked state is changing.
     * @since 0.0.55
     */
    onChange?: (checked: boolean) => void;
    /**
     * Tooltip for component
     * @since 0.0.55
     */
    tooltip?: ReactNode;
    /**
     * Indicates that Checkbox should be disabled
     * @since 0.0.55
     */
    disabled?: boolean;
    /**
     * @ignore
     */
    name?: string;
    /**
     * Indeterminate checked state of checkbox
     * @since 3.2.0
     */
    indeterminate?: boolean;
    /**
     * Label of the `Checkbox`
     * @since 0.0.55
     */
    children?: ReactNode;
    /**
     * Additional props for input element
     * @since 0.0.59
     */
    inputProps?: HTMLProps<HTMLInputElement>;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     * Right additional content.
     * @since 3.14.0
     */
    rightAddon?: ReactNode;
};
/**
 * `Checkbox` component is used for turning an option on or off and selecting or deselecting an item.
 * @since 0.0.55
 */
declare const Checkbox: FunctionComponent<CheckboxProps>;
export default Checkbox;
