import { FunctionComponent, ReactNode } from 'react';
export interface ColumnProps {
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    style?: object;
    /**
     * Content of the `Column`.
     * @since 2.6.0
     */
    children: ReactNode;
    /**
     * The column grows to absorb any extra free space in the columns container, and shrinks to its minimum size to fit the container.
     * @since 2.6.0
     */
    fill?: boolean;
    /**
     * Each column with a ratio property will fill space according to that column's relative ratio value compared to the sum of all columns with a ratio value specified.
     * @since 2.6.0
     */
    ratio?: 1 | 2 | 3;
    /**
     * Define column width. For the width specified as a number, `'px'` is used as the unit.
     * You can also specify a value with other units such as `'em'`, `'%'`, etc. (f.e. 20%, 10em)
     * @since 2.6.0
     */
    width?: number | string;
    /**
     * Define column minimum width. See `width` for details.
     * @since 2.6.0
     */
    minWidth?: number | string;
    /**
     * Define column maximum width. See `width` for details.
     * @since 2.6.0
     */
    maxWidth?: number | string;
}
/**
 * `Column` component is a part of [Columns](#!/Columns).
 * @since 2.6.0
 */
declare const Column: FunctionComponent<ColumnProps>;
export default Column;
