import { ComponentProps, ReactElement } from 'react';
import ComboBoxOption from './ComboBoxOption';
import './ComboBox.less';
export type ComboBoxProps = {
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    className?: string;
    /**
     * An initial value. It switches component into a controlled mode.
     * @since 2.6.0
     */
    value?: string;
    /**
     * An initial value.
     * @since 2.6.0
     */
    defaultValue?: string;
    /**
     * A callback executed when a value is changed.
     * @since 2.6.0
     */
    onChange?: (value: string) => void;
    /**
     * Whether disabled or not.
     * @since 2.6.0
     */
    disabled?: boolean;
    /**
     * Size of the ComboBox.
     * @since 2.6.0
     */
    size?: 'sm' | 'md' | 'lg' | 'xl' | 'fill';
    /**
     * Text alignment inside the input.
     * @since 2.6.0
     */
    textAlign?: 'left' | 'center' | 'right';
    /**
     * A placeholder for the input.
     * @since 2.6.0
     */
    placeholder?: string;
    /**
     * Array of ComboBoxOption.
     * @since 2.6.0
     */
    children: ReactElement<ComponentProps<typeof ComboBoxOption>>[];
};
/**
 * `ComboBox` component is a combination of [Select](#!/Select) and [Input](#!/Input)
 *  which allows to either enter a value directly into the field or choose from a list of existing options.
 * @since 2.6.0
 */
declare const ComboBox: ({ baseClassName, className, value, onChange, disabled, size, textAlign, placeholder, children, ...props }: ComboBoxProps) => import("react/jsx-runtime").JSX.Element;
declare const _default: {
    (props: ComponentProps<typeof ComboBox>): import("react/jsx-runtime").JSX.Element;
    displayName: string;
};
export default _default;
