import { ReactNode, ReactElement, FunctionComponent, ReactChild } from 'react';
import '../../helpers/base.less';
import '../Menu/Menu.less';
import './Dropdown.less';
import { Placement } from 'popper.js';
export type PopoverPlacement = Placement;
export interface DropdownProps {
    /**
     * Dropdown [menu](#!/Menu).
     * @type ReactElement
     * @since 0.0.57
     */
    menu: ReactElement;
    /**
     * Menu placement.
     * @since 0.0.60
     */
    menuPlacement?: PopoverPlacement;
    /**
     * Content of the `Dropdown`.
     * @type ReactChild
     * @since 0.0.57
     */
    children: ReactChild;
    /**
     * Custom localization messages.
     * @since 3.6.0
     */
    locale?: {
        close?: ReactNode;
    };
    /**
     * Display menu as overlay.
     * @ignore
     */
    overlay?: boolean;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
/**
 * `Dropdown` component is a [Button](#!/Button) that opens a drop-down (nested) [Menu](#!/Menu).
 * Use dropdown for grouping actions that are not used often or are less important than others -- in other words,
 * for stuff that you don't want to show users all the time, especially if you have limited screen space.
 * @since 0.0.57
 */
declare const Dropdown: FunctionComponent<DropdownProps>;
export default Dropdown;
