import { ComponentProps, ReactNode } from 'react';
import FormField from '../FormField';
import '../../helpers/base.less';
import './FormFieldCheckbox.less';
export interface FormFieldCheckboxProps extends ComponentProps<typeof FormField> {
    /**
     * Disabled state of field.
     * @since 0.1.0
     */
    disabled?: boolean;
    /**
     * Custom checked value. Default is boolean true.
     * @since 0.0.59
     */
    checkedValue?: boolean | string;
    /**
     * Custom unchecked value. Default is boolean false.
     * @since 0.0.59
     */
    uncheckedValue?: boolean | string;
    /**
     * The browser will automatically focus on the component upon rendering the screen
     * @since 1.9.0
     */
    autoFocus?: boolean;
    /**
     * @ignore
     */
    label?: ReactNode;
    /**
     * @ignore
     */
    required?: boolean;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * Adds an info icon with the additional description.
     */
    fullDescription?: string;
}
/**
 * `FormFieldCheckbox` component is used for turning an option on or off
 * and selecting or deselecting an item.
 * @since 0.0.58
 */
declare const FormFieldCheckbox: ({ className, label, autoFocus, required, checkedValue, uncheckedValue, baseClassName, ...props }: FormFieldCheckboxProps) => import("react/jsx-runtime").JSX.Element;
export default FormFieldCheckbox;
