import { ReactElement, ReactNode, FunctionComponent, ComponentProps } from 'react';
import FormField from '../FormField';
import './FormFieldRadioButtons.less';
export interface FormFieldRadioButtonsProps extends ComponentProps<typeof FormField> {
    /**
     * @since 0.2.0
     */
    options: {
        /**
         * Option value.
         */
        value: string;
        /**
         * Option label.
         */
        label: ReactNode;
        /**
         * Text hint located below option for providing additional information.
         */
        description?: ReactNode;
        /**
         * Set true if option is not available to choice.
         */
        disabled?: boolean;
        /**
         * Optional array of `FormField` components under this option.
         */
        indentFields?: ReactElement[];
    }[];
    /**
     * Value of current chosen option.
     * @deprecated Use [Form](#!/Form) values.
     * @since 0.2.0
     */
    value?: string;
    /**
     * Disabled state of field.
     * @since 0.2.0
     */
    disabled?: boolean;
    /**
     * The browser will automatically focus on the component upon rendering the screen
     * @since 1.9.0
     */
    autoFocus?: boolean;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    label?: ReactNode;
    /**
     * @ignore
     */
    name?: string;
    /**
     * @ignore
     */
    required?: boolean;
}
/**
 * `FormFieldRadioButtons` is used for making a choice among a set of mutually exclusive, related options. Only one option can be chosen.
 * @since 0.2.0
 */
declare const FormFieldRadioButtons: FunctionComponent<FormFieldRadioButtonsProps>;
export default FormFieldRadioButtons;
