import { ComponentProps, FunctionComponent } from 'react';
import FormField from '../FormField';
import { InputProps } from '../Input';
import { TextAreaProps } from '../TextArea';
import './FormFieldText.less';
type MultilineProps = {
    multiline: true;
    inputProps?: Partial<TextAreaProps>;
};
type SingleLineProps = {
    multiline?: false;
    inputProps?: Partial<InputProps>;
};
type LinePropsBase = MultilineProps | SingleLineProps;
export type FormFieldTextProps = ComponentProps<typeof FormField> & {
    /**
     * Size of the input
     * @since 0.0.58
     */
    size?: 'sm' | 'md' | 'lg' | 'xl' | 'fill';
    /**
     * If `true`, a textarea element will be rendered.
     * @since 1.3.0
     */
    multiline?: boolean;
    /**
     * Number of rows to display when multiline option is set to true.
     * @since 1.3.0
     */
    rows?: number | {
        min: number;
        max: number;
    };
    /**
     * Placeholder of the input
     * @since 0.0.58
     */
    placeholder?: string;
    /**
     * Disabled state of field.
     * @since 0.2.0
     */
    disabled?: boolean;
    /**
     * The browser will automatically focus on the component upon rendering the screen
     * @since 1.9.0
     */
    autoFocus?: boolean;
    /**
     * Whether the value of the control can be automatically completed by the browser or not.
     * @since 2.5.1
     */
    autoComplete?: string;
    /**
     * If 'true', a field will be multiple. You can also limit the number of fields with a value like { max: 5 }.
     * @since 1.12.0
     */
    multi?: boolean | {
        max: number;
    };
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * Adjust height automatically when multiline option is set to true.
     * @since 1.9.0
     */
    autoheight?: boolean;
} & LinePropsBase;
/**
 * `FormFieldText` component is used for entering of user data in text format.
 *
 * [FormField](#!/FormField) with [InputNumber](#!/InputNumber) can be used for entering of integer numbers.
 * @since 0.0.58
 */
declare const FormFieldText: FunctionComponent<FormFieldTextProps>;
export default FormFieldText;
