import { ReactNode, ReactElement, ElementType, FunctionComponent } from 'react';
import { IconName, IconProps } from '../Icon';
import './Heading.less';
export type HeadingProps = {
    /**
     * Importance of the `Title`. Render as h1, h2, etc.
     * @since 2.3.0
     */
    level?: 1 | 2 | 3 | 4 | 5 | 6;
    /**
     * Icon of the `Heading`.
     * @since 3.10.0
     */
    icon?: IconName | IconProps | ReactElement<any>;
    /**
     * Content of the `Heading`.
     * @since 2.3.0
     */
    children: ReactNode;
    /**
     * Component to render as the root element.
     * @since 2.3.0
     */
    component?: string | ElementType;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
};
/**
 * `Heading` is used as a text title (or a subtitle) to define the hierarchy and the structure of the content.
 * @since 2.3.0
 */
declare const Heading: FunctionComponent<HeadingProps>;
export default Heading;
