import { FunctionComponent, ReactElement } from 'react';
import { IconProps } from '../Icon';
import './InputNumber.less';
export interface InputNumberProps {
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    className?: string;
    /**
     * An initial value.
     * @since 2.2.0
     */
    defaultValue?: number;
    /**
     * An initial value. It switches component into a controlled mode.
     * @since 2.2.0
     */
    value?: number;
    /**
     * The minimum value to accept for this input.
     * @since 2.2.0
     */
    min?: number;
    /**
     * The maximum value to accept for this input.
     * @since 2.2.0
     */
    max?: number;
    /**
     * A stepping interval.
     * @since 2.2.0
     */
    step?: number;
    /**
     * Disabled state of field.
     * @since 2.2.0
     */
    disabled?: boolean;
    /**
     * A callback executed when a value is changed.
     * @since 2.2.0
     */
    onChange?: (value: number) => void;
    /**
     * An icon for the decrement button.
     * @since 2.3.0
     */
    decrementIcon?: string | IconProps | ReactElement<any>;
    /**
     * An icon for the increment button.
     * @since 2.3.0
     */
    incrementIcon?: string | IconProps | ReactElement<any>;
    /**
     * Size of the input.
     * @since 2.3.0
     */
    size?: number | 'sm' | 'md' | 'lg' | 'xl' | 'fill';
}
/**
 * `InputNumber` component is used for entering integer numbers.
 * @since 2.2.0
 */
declare const InputNumber: FunctionComponent<InputNumberProps>;
export default InputNumber;
