import { FunctionComponent, ReactElement, ReactNode, MouseEvent } from 'react';
type TextFunction = (params: {
    selectedRows: ReactNode;
    selectedRowTitle: ReactNode;
}) => ReactNode;
export type ListOperationProps = {
    /**
     * Whether a critical operation or not. E.g. updating, deleting are critical operations.
     * @since 2.4.0
     */
    critical?: boolean;
    /**
     * The text displayed when the action for selected items needs to be confirmed.
     * @since 2.4.0
     */
    confirmationText?: ReactNode | TextFunction;
    /**
     * The text displayed when no item is selected.
     * @since 2.4.0
     */
    noSelectionText?: ReactNode | TextFunction;
    /**
     * The text for the action button.
     * @since 2.4.0
     */
    actionButtonText?: ReactNode | TextFunction;
    /**
     * The text for the cancel button.
     * @since 2.4.0
     */
    cancelButtonText?: ReactNode | TextFunction;
    /**
     * A wrapped element.
     * @since 2.4.0
     */
    children: ReactElement<{
        onClick: (e: MouseEvent) => void;
    }>;
};
/**
 * `ListOperation` component is used in [Toolbar](#!/Toolbar) for performing
 * operations on multiple objects in [List](#!/List).
 * @since 2.4.0
 */
declare const ListOperation: FunctionComponent<ListOperationProps>;
export default ListOperation;
