import { ReactNode, HTMLProps } from 'react';
import './Media.less';
export interface MediaProps extends Omit<HTMLProps<HTMLDivElement>, 'title'> {
    /**
     * Title
     * @since 0.0.45
     */
    title?: ReactNode;
    /**
     * Title addon
     * @since 0.0.68
     */
    titleAddon?: ReactNode;
    /**
     * Title size
     * @deprecated Pass a component as a title prop
     * @since 0.0.68
     */
    titleSize?: 'md' | 'lg' | 'xl';
    /**
     * Image
     * @since 0.0.45
     */
    image?: ReactNode;
    /**
     * Spacings between image and content
     * @since 0.3.0
     */
    imageSpacing?: 'sm' | 'md' | 'lg' | 'xl' | 'xxl';
    /**
     * Media object and content alignment
     * @since 3.19.0
     */
    align?: 'start' | 'center' | 'end';
    /**
     * Media object (image) alignment
     * @since 3.19.0
     */
    imageAlign?: 'start' | 'center' | 'end';
    /**
     * Media vertical direction
     * @since 3.19.0
     */
    vertical?: boolean;
    /**
     * Content of the `Media`.
     * @since 0.0.45
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
/**
 * `Media` component is a combination of icon, text title and content.
 * This layout was so widely spread in our products so we have decided to create a special component for it.
 * Probably we should have named the component differently (not Media), but we didn't have better idea then ;)
 * @since 0.0.45
 */
declare const Media: ({ className, children, title, titleAddon, titleSize, image, imageSpacing, imageAlign, align, vertical, baseClassName, ...props }: MediaProps) => import("react/jsx-runtime").JSX.Element;
export default Media;
