import { ReactNode, HTMLAttributes } from 'react';
import '../../helpers/base.less';
import './Menu.less';
export interface MenuProps extends HTMLAttributes<HTMLDivElement> {
    /**
     * Triggered when menu item was clicked.
     * @since 0.0.56
     */
    onItemClick?: (test: ReactNode, index: number) => void;
    /**
     * Content of the `Menu`.
     * @since 0.0.55
     */
    children?: ReactNode;
    /**
     * Show menu in overlay.
     * @ignore
     */
    overlay?: boolean;
    /**
     * Role of the menu. Default is "menu".
     * "listbox" is used for dropdown and multiselect variants.
     */
    role?: 'menu' | 'listbox';
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
/**
 * `Menu` component displays grouped controls for navigating the UI, performing actions on objects, or showing
 * options for [Lists](#!/List) (for example, sorting and filtering settings). `Menu` is most typically used in a
 * [Dropdown](#!/Dropdown).
 *
 * `Menu` consists of several [Menu Items](#!/MenuItem) (or [Selectable Menu
 * Items](#!/MenuSelectableItem)) which can be grouped by [Menu Headers](#!/MenuHeader)
 * or separated by [Menu Dividers](#!/MenuDivider).
 * @since 0.0.55
 */
declare const Menu: import("react").ForwardRefExoticComponent<MenuProps & import("react").RefAttributes<HTMLElement>>;
export default Menu;
