import { ElementType, ReactNode } from 'react';
import { MenuBaseItemProps } from './MenuBaseItem';
import { IconName, IconProps } from '../Icon';
export type MenuItemProps<Component extends ElementType = 'div'> = {
    /**
     * Whether item is active.
     * @since 0.0.55
     */
    active?: boolean;
    /**
     * Whether item is disabled.
     * @since 0.0.55
     */
    disabled?: boolean;
    /**
     * Icon
     * @since 0.0.55
     */
    icon?: IconName | IconProps | ReactNode;
    /**
     * Right label of item.
     * @since 0.0.57
     */
    label?: ReactNode;
    /**
     * Tooltip for component.
     * @since 2.6.1
     */
    tooltip?: ReactNode;
    /**
     * Role of the parent menu. Default is "menu".
     * "listbox" is used for dropdown and multiselect variants.
     */
    menuRole?: 'menu' | 'listbox';
    /**
     * Content of the `MenuItem`.
     * @since 0.0.55
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
} & MenuBaseItemProps<Component>;
/**
 * `MenuItem` is a part of [Menu](#!/Menu) component.
 * @since 0.0.55
 */
declare const MenuItem: <Component extends ElementType = "div">({ className, children, onClick, icon, label, tooltip, menuRole, baseClassName, disabled, active, ...props }: MenuItemProps<Component>) => import("react/jsx-runtime").JSX.Element;
export default MenuItem;
