import { ReactNode, HTMLAttributes, CSSProperties, ReactElement } from 'react';
import '../../helpers/base.less';
import './Overlay.less';
export type OverlayProps = {
    /**
     * Toggles visibility.
     */
    isOpen?: boolean;
    /**
     * Overlay placement.
     */
    placement?: 'center' | 'left' | 'right';
    /**
     * Overlay size.
     */
    size?: 'xs' | 'sm' | 'md' | 'lg';
    /**
     * onClose handler.
     */
    onClose?: () => void;
    /**
     * Indicating if clicking the backdrop should close the overlay.
     */
    canCloseOnBackdropClick?: boolean;
    /**
     * Indicating if pressing the escape key should close the overlay.
     */
    canCloseOnEscapePress?: boolean;
    /**
     * Block with an image, placed at the side of the component
     * @since 3.25.0
     */
    sideBanner?: string | ReactElement | HTMLAttributes<HTMLImageElement>;
    /**
     * Additional properties for the sideBanner
     * @since 3.25.0
     */
    sideBannerContainer?: {
        /**
         * Values for css background property
         */
        background: string;
        /**
         * One of css align-items property value: center, start, end, etc.
         */
        align?: CSSProperties['alignItems'];
    };
    /**
     * @ignore
     */
    style?: CSSProperties;
    /**
     * Content of the `Overlay`.
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    containerProps?: Omit<HTMLAttributes<HTMLDivElement>, 'onFocus'>;
};
declare const Overlay: ({ isOpen, ...props }: OverlayProps) => import("react/jsx-runtime").JSX.Element | null;
export default Overlay;
