import { FunctionComponent, ReactNode, HTMLProps } from 'react';
import { DataAttributes } from '../../utils/types';
import './PageHeader.less';
export type PageHeaderProps = {
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    className?: string;
    /**
     * A slot for some promotion.
     * @since 2.3.0
     */
    topAddon?: ReactNode;
    /**
     * A title. It renders with `Heading` component by default.
     * @since 2.3.0
     */
    title?: ReactNode;
    /**
     * A slot for an icon before the title.
     * @since 2.3.0
     */
    titleLeftAddon?: ReactNode;
    /**
     * A slot for a button after the title.
     * @since 2.3.0
     */
    titleRightAddon?: ReactNode;
    /**
     * A slot for `Breadcrumbs` component.
     * @since 2.3.0
     */
    breadcrumbs?: ReactNode;
    /**
     * A content. It uses for description.
     * @since 0.0.47
     */
    children?: ReactNode;
    /**
     * A slot for `Tabs` component.
     * @since 2.3.0
     */
    tabs?: ReactNode;
} & Omit<HTMLProps<HTMLDivElement>, 'title'> & DataAttributes;
/**
 * `PageHeader` component is used for identification of the current page.
 * @since 0.0.35
 */
declare const PageHeader: FunctionComponent<PageHeaderProps>;
export default PageHeader;
