import { FunctionComponent } from 'react';
import './Pagination.less';
type ItemPerPageOption = number | 'all';
export declare const ITEMS_PER_PAGE_OPTIONS: ItemPerPageOption[];
declare const VIEW_DEFAULT = "default";
declare const VIEW_POPOVER = "popover";
export type PaginationProps = {
    /**
     * Number of pages in pagination.
     * @since 0.0.54
     */
    total: number;
    /**
     * Current page number.
     * @since 0.0.54
     */
    current?: number;
    /**
     * On select callback.
     * @since 0.0.54
     */
    onSelect: (page: number) => void;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * The number of items per page.
     * @since 2.3.0
     */
    itemsPerPage?: ItemPerPageOption;
    /**
     * Available options for selecting the number of items per page.
     * @since 2.3.0
     */
    itemsPerPageOptions?: ItemPerPageOption[];
    /**
     * A callback fired when the number of items per page is changed.
     * @since 2.3.0
     */
    onItemsPerPageChange?: (option: ItemPerPageOption) => void;
    /**
     * View mode.
     * @since 2.4.0
     */
    view?: typeof VIEW_DEFAULT | typeof VIEW_POPOVER;
    /**
     * Indicate the loading state of the pagination.
     * @since 3.3.1
     */
    loading?: boolean;
    /**
     * This property was removed.
     * @ignore
     */
    isShowNavigationButtons?: boolean;
    /**
     * This property was removed.
     * @ignore
     */
    isShowPageButtons?: boolean;
    /**
     * This property was removed.
     * @ignore
     */
    maxPageButtons?: number;
};
/**
 * `Pagination` component is used for navigating objects in [List](#!/List) which content is displayed on multiple pages.
 * @since 0.0.54
 */
declare const Pagination: FunctionComponent<PaginationProps>;
export default Pagination;
