import { HTMLAttributes, ReactNode } from 'react';
import { ComponentProps } from '../../utils/types';
import './Panel.less';
export interface PanelBaseProps {
    /**
     * Panel title.
     * @since 0.0.37
     */
    title?: ReactNode;
    /**
     * A slot for buttons or links in the header.
     * @since 2.5.0
     */
    extra?: ReactNode;
    /**
     * Is panel collapsible.
     * @since 0.0.35
     */
    collapsible?: boolean;
    /**
     * Whether collapsed or not.
     * @since 0.0.35
     */
    collapsed?: boolean;
    /**
     * A callback executed when the panel is expanding or collapsing.
     * @since 0.0.35
     */
    onToggle?: (collapsed: boolean) => void;
    /**
     * Content of the panel.
     * @since 0.0.47
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
export type PanelProps = ComponentProps<PanelBaseProps, HTMLAttributes<HTMLDivElement>>;
/**
 * `Panel` component is used for visually grouping some content.
 * @since 0.0.35
 */
declare const Panel: ({ baseClassName, className, title, collapsible, collapsed: externalCollapsed, onToggle, children, extra, ...props }: PanelProps) => import("react/jsx-runtime").JSX.Element;
export default Panel;
