import { ReactNode } from 'react';
import { IconName, IconProps } from '../Icon';
import '../../helpers/base.less';
import './ProgressStep.less';
export declare const STATUS_NOT_STARTED = "not_started";
export declare const STATUS_RUNNING = "running";
export declare const STATUS_DONE = "done";
export declare const STATUS_WARNING = "warning";
export declare const STATUS_ERROR = "error";
export declare const STATUS_CANCELED = "canceled";
export declare const PROGRESS_STEP_DEFAULT_STATUS = "not_started";
export type Status = typeof STATUS_NOT_STARTED | typeof STATUS_RUNNING | typeof STATUS_DONE | typeof STATUS_ERROR | typeof STATUS_CANCELED | typeof STATUS_WARNING;
export interface ProgressStepProps {
    /**
     * Title of the step
     * @since 1.10.0
     */
    title?: ReactNode;
    /**
     * Status for the step
     * @since 1.10.0
     */
    status?: Status;
    /**
     * Name of icon or [Icon](#!/Icon) component
     * @ignore
     */
    icon?: ReactNode | IconName | IconProps;
    /**
     * Text description for the status of the step
     * @since 1.10.0
     */
    statusText?: ReactNode;
    /**
     * Progress indication in numbers
     * @since 1.10.0
     */
    progress?: number;
    /**
     * Content of the `ProgressStep`.
     * @since 1.10.0
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
/**
 * `ProgressStep` is a part of the [Progress](#!/Progress) component.
 * @since 1.10.0
 */
declare const ProgressStep: ({ className, children, icon, title, statusText, progress, status, baseClassName, ...props }: ProgressStepProps) => import("react/jsx-runtime").JSX.Element;
export default ProgressStep;
