import { ReactNode, HTMLProps, FunctionComponent, HTMLAttributes } from 'react';
import { DataAttributes } from '../../utils/types';
import './Radio.less';
type BaseRadioProps = {
    /**
     * Determine whether the `Radio` is checked.
     * @since 3.2.0
     */
    checked?: boolean;
    /**
     * @ignore
     */
    defaultChecked?: boolean;
    /**
     * A callback function, can be executed when the checked state is changing.
     * @since 3.2.0
     */
    onChange?: (checked: boolean) => void;
    /**
     * Indicates that Checkbox should be disabled
     * @since 3.2.0
     */
    disabled?: boolean;
    /**
     * Field name
     * @since 3.2.0
     */
    name?: string;
    /**
     * Label of the `Radio`
     * @since 3.2.0
     */
    children?: ReactNode;
    /**
     * Additional props for input element
     * @since 3.2.0
     */
    inputProps?: HTMLProps<HTMLInputElement>;
    /**
     * @ignore
     */
    baseClassName?: string;
};
export type RadioProps = BaseRadioProps & DataAttributes & Omit<HTMLAttributes<HTMLLabelElement>, keyof BaseRadioProps>;
/**
 * `Radio` component is used for making a choice among a set of mutually exclusive, related options.
 * @since 3.2.0
 */
declare const Radio: FunctionComponent<RadioProps>;
export default Radio;
