import { ReactNode } from 'react';
import { InPlaceEditProps } from '../InPlaceEdit';
import './Section.less';
export interface SectionProps {
    /**
     * Title of the section.
     * @since 0.0.54
     */
    title?: ReactNode;
    /**
     * Visual intent color to apply to component.
     * @since 0.0.54
     */
    intent?: 'danger' | 'warning' | 'success' | 'inactive';
    /**
     * Is section collapsible.
     * @since 0.0.54
     */
    collapsible?: boolean;
    /**
     * Is section collapsed now.
     * @since 0.0.54
     */
    collapsed?: boolean;
    /**
     * Event handler of title change with inline editing form.
     * @since 0.0.54
     */
    onTitleChange?: InPlaceEditProps['onChange'];
    /**
     * Event handler of closing section with X-sign at the right.
     * @since 0.0.54
     */
    onClose?: () => void;
    /**
     * A callback executed when the section collapsing.
     * @since 3.26.0
     */
    onToggle?: (collapsed: boolean) => void;
    /**
     * Array of custom section action button at the right.
     * @since 0.0.54
     */
    buttons?: ReactNode[];
    /**
     * Vertical or horizontal section view.
     * Section view will be automatically switched if this parameter is not specified explicitly.
     * @since 0.3.0
     */
    vertical?: boolean;
    /**
     * Content of the `Section`.
     * @since 0.0.54
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
export declare const SECTION_BASE_CLASS_NAME: string;
/**
 * `Section` component is used for dividing of complex content into groups for better readability
 * and comprehension of the presented information.
 * @since 0.0.54
 */
declare const Section: ({ baseClassName, className, intent, collapsible, collapsed: externalCollapsed, onToggle, title, onTitleChange, onClose, buttons, vertical: externalVertical, children, ...props }: SectionProps) => import("react/jsx-runtime").JSX.Element;
export default Section;
