import { ComponentType, FC, JSX, CSSProperties } from 'react';
import './Skeleton.less';
export type SkeletonProps = {
    /**
     * Skeleton width. For the width specified as a number, `'px'` is used as the unit.
     * You can also specify a value with other units such as `'em'`, `'%'`, etc. (f.e. 20%, 10em)
     * @since 3.28.0
     */
    width?: number | string;
    /**
     * Skeleton max width. For the width specified as a number, `'px'` is used as the unit.
     * You can also specify a value with other units such as `'em'`, `'%'`, etc. (f.e. 20%, 10em)
     * @since 3.28.0
     */
    maxWidth?: number | string;
    /**
     * Skeleton height. For the width specified as a number, `'px'` is used as the unit.
     * You can also specify a value with other units such as `'em'`, `'%'`, etc. (f.e. 20%, 10em)
     * @since 3.28.0
     */
    height?: number | string;
    /**
     * Custom styles for skeleton
     * @since 3.28.0
     */
    style?: CSSProperties;
    /**
     * Component to render as the root element.
     * @since 3.28.0
     */
    component?: ComponentType | keyof JSX.IntrinsicElements;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    className?: string;
};
/**
 * `Skeleton` (or content-placeholder) is placeholder preview of content before the data gets loaded to reduce load-time frustration.
 * Skeleton is used for non-text components, images, media-objects, etc.
 * @since 3.28.0
 */
declare const Skeleton: FC<SkeletonProps>;
export default Skeleton;
