import { ReactNode, KeyboardEventHandler } from 'react';
import { ButtonProps } from '../Button';
import { DropdownProps } from '../Dropdown';
import './SplitButton.less';
export interface SplitButtonProps {
    /**
     * Dropdown [menu](#!/Menu)
     * @type ReactElement
     * @since 0.0.47
     */
    menu: DropdownProps['menu'];
    /**
     * Name of icon or [Icon](#!/Icon) component
     * @type IconName | IconProps | ReactNode
     * @since 3.35.0
     */
    icon?: ButtonProps['icon'];
    /**
     * Button size
     * @since 3.35.0
     */
    size?: ButtonProps['size'];
    /**
     * Content of the button
     * @since 0.0.40
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    onKeyDown?: KeyboardEventHandler<HTMLDivElement>;
    /**
     * @ignore
     */
    onClick?: ButtonProps['onClick'];
}
/**
 * `Split Button` is a combination of a standard [Button](#!/Button) with a [Dropdown](#!/Dropdown) menu.
 * It is used for grouping several related actions when one of the actions should be accessible immediately
 * because it is used more often than others.
 * @since 0.0.40
 */
declare const SplitButton: ({ baseClassName, className, menu, children, onClick, onKeyDown, icon, size, ...props }: SplitButtonProps) => import("react/jsx-runtime").JSX.Element;
export default SplitButton;
