import { ReactElement, ReactNode } from 'react';
import { SpotPulsarProps } from './SpotPulsar';
export interface SpotProps extends Omit<SpotPulsarProps, 'rect'> {
    /**
     * A css selector for the node that should be highlighted.
     * @since 3.0.1
     */
    selector: string;
    /**
     * Placement of the pulsar on the target node. By default, it places in the center of the node.
     * @since 3.0.1
     */
    placement?: 'left' | 'center' | 'right';
    /**
     * A popup displayed when the spot is active.
     * @since 3.0.1
     */
    popup?: {
        /**
         * @ignore
         */
        className?: string;
        /**
         * A size of the popup.
         */
        size?: 'xs' | 'sm' | 'md';
        /**
         * Placement of the popup.
         */
        placement?: 'auto' | 'top-left' | 'top' | 'top-right' | 'right-top' | 'right' | 'right-bottom' | 'bottom-right' | 'bottom' | 'bottom-left' | 'left-bottom' | 'left' | 'left-top';
        /**
         * Buttons with some actions (go to next spot, previous, etc.).
         */
        buttons?: ReactElement[];
        /**
         * A title for the popup.
         */
        title?: ReactNode;
        /**
         * An URL to some image or React element.
         */
        image?: ReactNode;
        /**
         * Custom localization messages.
         */
        locale?: {
            total?: ReactNode;
        };
        /**
         * A callback fired when the popup is closed.
         */
        onClose?: () => void;
        /**
         * Content of the popup.
         */
        children?: ReactNode;
    };
    /**
     * @ignore
     */
    meta?: {
        current: number;
        total: number;
    };
}
/**
 * The component can be used to attract the user's attention to a specific element on the page.
 * @since 3.0.1
 */
declare const Spot: ({ selector, popup, meta, placement, ...props }: SpotProps) => import("react/jsx-runtime").JSX.Element | null;
export default Spot;
