import { ReactNode, ReactElement, FunctionComponent } from 'react';
import { IconProps } from '../Icon';
import '../../helpers/base.less';
import './Status.less';
type IconType = boolean | string | IconProps | ReactElement<any>;
export type Intent = 'danger' | 'warning' | 'success' | 'info' | 'muted' | 'inactive';
export type StatusProps = {
    /**
     * Content of the `Status`.
     * @since 0.0.68
     */
    children?: ReactNode;
    /**
     * Icon of the Status.
     * @since 0.0.68
     */
    icon?: IconType;
    /**
     * Visual intent color to apply to component.
     * @since 0.0.68
     */
    intent?: Intent;
    /**
     * Compact version with the dot indicator instead of icon.
     * @since 2.1.0
     */
    compact?: boolean;
    /**
     * Place icon on the opposite side.
     * @since 2.1.0
     */
    flip?: boolean;
    /**
     * Right additional content.
     * @since 0.0.68
     */
    rightAddon?: ReactNode;
    /**
     * Bottom additional content.
     * @since 0.0.68
     */
    bottomAddon?: ReactNode;
    /**
     * Indicate the progress state of the `Status`.
     * @since 1.1.0
     */
    progress?: boolean;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * Props for the outer element.
     * @since 2.1.0
     */
    outerProps?: {
        className?: string;
    };
};
/**
 * `Status` component is used for indicating state of an object or the system.
 * @since 0.0.68
 */
declare const Status: FunctionComponent<StatusProps>;
export default Status;
