import { ReactElement } from 'react';
import { TabProps } from './Tab';
import '../../helpers/base.less';
import { SearchBarProps } from './SearchBar';
import './Tabs.less';
export interface TabsProps {
    /**
     * Number of active tab
     * @since 0.0.35
     */
    active?: number;
    /**
     * Addon for search bar, dropdown etc.
     * @since 0.0.58
     */
    addon?: ReactElement;
    /**
     * Placeholder for search bar, dropdown etc.
     *
     * @deprecated Do not use! Use `addon` instead!
     * @since 0.0.42
     */
    placeholder?: ReactElement;
    /**
     * Minimum add-on width in pixels
     * @since 0.0.58
     */
    addonMinWidth?: number;
    /**
     * Monospaced version of tabs (all visible tabs as wide as widest of them)
     * @since 0.0.58
     */
    monospaced?: boolean;
    /**
     * [SearchBar](#!/SearchBar) element
     * @since 0.0.58
     */
    search?: ReactElement<SearchBarProps>;
    /**
     * [Tabs](#!/Tab)
     * @since 0.0.47
     */
    children: ReactElement<TabProps> | ReactElement<TabProps>[];
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
}
/**
 * `Tabs` component is a content area with a group of individual [Tab](#!/Tab) elements, each displaying different content
 * in the same screen area. `Tabs` are used when you have too much content to display in one place at the same time, so
 * the content is broken into logical groups and each group is displayed under its own [Tab](#!/Tab) that serves both as a
 * group name and a navigation button.
 * @since 0.0.35
 */
declare const Tabs: ({ baseClassName, className, addon, placeholder, children, active: externalActive, addonMinWidth, monospaced, search, ...props }: TabsProps) => import("react/jsx-runtime").JSX.Element | null;
export default Tabs;
