import { ReactNode, ElementType, FunctionComponent } from 'react';
import '../../helpers/base.less';
import './Text.less';
export type TextProps = {
    /**
     * Content of the `Text`.
     * @since 1.1.0
     */
    children: ReactNode;
    /**
     * Component to render as the root element.
     * @since 1.1.0
     */
    component?: string | ElementType;
    /**
     * Visual intent color to apply to component.
     * @since 1.1.0
     */
    intent?: 'info' | 'success' | 'warning' | 'danger' | 'muted';
    /**
     * Font size to apply to component.
     * @since 2.3.0
     */
    fontSize?: 'sm' | 'md';
    /**
     * Indicates that contents have strong importance.
     * @since 1.1.0
     */
    bold?: boolean;
    /**
     * Indicates that contents are set off from the normal text for some reason.
     * @since 1.1.0
     */
    italic?: boolean;
    /**
     * Marked text.
     * @since 3.7.0
     */
    mark?: boolean;
    /**
     * Truncate the text with an ellipsis.
     * @since 3.1.0
     */
    truncate?: boolean;
    /**
     * Prevent text from wrapping.
     * @since 3.1.0
     */
    nowrap?: boolean;
    /**
     * @ignore
     */
    className?: string;
    /**
     * @ignore
     */
    baseClassName?: string;
};
/**
 * `Text` component is used for displaying inline text. For text blocks use [Paragraph](#!/Paragraph).
 * @since 1.1.0
 */
declare const Text: FunctionComponent<TextProps>;
export default Text;
