import { ComponentPropsWithoutRef, ChangeEventHandler } from 'react';
import { DataAttributes } from '../../utils/types';
import './TextArea.less';
type Rows = number | {
    min: number;
    max: number;
};
export type TextAreaProps = {
    /**
     * @ignore
     */
    baseClassName?: string;
    /**
     * @ignore
     */
    className?: string;
    /**
     * Textarea width.
     * @since 1.9.0
     */
    size?: 'sm' | 'md' | 'lg' | 'xl' | 'fill';
    /**
     * Adjust height automatically when multiline option is set to true.
     * @since 1.9.0
     */
    autoheight?: boolean;
    /**
     * Number of rows, can be a range.
     * @since 1.9.0
     */
    rows?: Rows;
    /**
     * @ignore
     */
    onChange?: ChangeEventHandler<HTMLTextAreaElement>;
} & Omit<ComponentPropsWithoutRef<'textarea'>, 'rows'> & DataAttributes;
/**
 * `TextArea` is used for entering long text (like email body, descriptions, comments).
 * @since 1.9.0
 */
declare const TextArea: ({ baseClassName, className, rows, size, autoheight, onChange, style, ...props }: TextAreaProps) => import("react/jsx-runtime").JSX.Element;
export default TextArea;
